.. _Python Programming Language: http://www.python.org/
.. _Python Standard Library: http://docs.python.org/library/
.. _GPL License: http://www.opensource.org/licenses/gpl-license.php
.. _circuits framework: http://packages.python.org/circuits
.. _circuits-bricks: http://pypi.python.org/pypi/circuits-bricks
.. _rbtranslations: http://pypi.python.org/pypi/rbtranslations
.. _Package Documentation: http://packages.python.org/cocy
.. _github: https://github.com/mnlipp/CoCy
.. _issue tracker: https://github.com/mnlipp/CoCy/issues 

Overview
--------

CoCy provides components for UPnP based on 
the `circuits framework`_. Read the `Package Documentation`_
for details.

The source is maintained at `github`_. Please use the `issue tracker`_ 
there to report any issues.

Requirements
------------

CoCy depends on the `Python Standard Library`_,
the `circuits framework`_ in the 2.1 version,
the general purpose `circuits_bricks` components and the
`rbtranslations` library. 

Installation
------------

The simplest and recommended way to install CoCy is with 
easy_install::

    > easy_install cocy

Alternatively, you may download the source package from the
`cocy Page on PyPI`_ or from `github`_, extract it 
and install using::

    > python setup.py install

License
-------

CoCy is licensed under the `GPL License`_.

